Connection

Struct Connection 

pub struct Connection(/* private fields */);
Available on crate feature fullstack only.
Connection header, defined in RFC7230

The Connection header field allows the sender to indicate desired control options for the current connection. In order to avoid confusing downstream recipients, a proxy or gateway MUST remove or replace any received connection options before forwarding the message.

ABNF

Connection        = 1#connection-option
connection-option = token

# Example values
* `close`
* `keep-alive`
* `upgrade`

Examples

use headers::Connection;

let keep_alive = Connection::keep_alive();

Implementations

Source

impl Connection

pub fn close() -> Connection

A constructor to easily create a Connection: close header.

pub fn keep_alive() -> Connection

A constructor to easily create a Connection: keep-alive header.

pub fn upgrade() -> Connection

A constructor to easily create a Connection: Upgrade header.

pub fn contains(&self, name: impl AsConnectionOption) -> bool

Check if this header contains a given “connection option”.

This can be used with various argument types:

  • &str
  • &HeaderName
  • HeaderName
Example
extern crate http;

use http::header::UPGRADE;
use headers::Connection;

let conn = Connection::keep_alive();

assert!(!conn.contains("close"));
assert!(!conn.contains(UPGRADE));
assert!(conn.contains("keep-alive"));
assert!(conn.contains("Keep-Alive"));