ContentDisposition

Struct ContentDisposition 

pub struct ContentDisposition(/* private fields */);
Available on crate feature fullstack only.
A Content-Disposition header, (re)defined in RFC6266.

The Content-Disposition response header field is used to convey additional information about how to process the response payload, and also can be used to attach additional metadata, such as the filename to use when saving the response payload locally.

ABNF

content-disposition = "Content-Disposition" ":"
                      disposition-type *( ";" disposition-parm )

disposition-type    = "inline" | "attachment" | disp-ext-type
                      ; case-insensitive

disp-ext-type       = token

disposition-parm    = filename-parm | disp-ext-parm

filename-parm       = "filename" "=" value
                    | "filename*" "=" ext-value

disp-ext-parm       = token "=" value
                    | ext-token "=" ext-value

ext-token           = <the characters in token, followed by "*">

Example

use headers::ContentDisposition;

let cd = ContentDisposition::inline();

Implementations

Source

impl ContentDisposition

pub fn inline() -> ContentDisposition

Construct a Content-Disposition: inline header.

pub fn is_inline(&self) -> bool

Check if the disposition-type is inline.

pub fn is_attachment(&self) -> bool

Check if the disposition-type is attachment.

pub fn is_form_data(&self) -> bool

Check if the disposition-type is form-data.