ContentLength

Struct ContentLength 

pub struct ContentLength(pub u64);
Available on crate feature fullstack only.
Content-Length header, defined in RFC7230

When a message does not have a Transfer-Encoding header field, a Content-Length header field can provide the anticipated size, as a decimal number of octets, for a potential payload body. For messages that do include a payload body, the Content-Length field-value provides the framing information necessary for determining where the body (and message) ends. For messages that do not include a payload body, the Content-Length indicates the size of the selected representation.

Note that setting this header will remove any previously set Transfer-Encoding header, in accordance with RFC7230:

A sender MUST NOT send a Content-Length header field in any message that contains a Transfer-Encoding header field.

ABNF

Content-Length = 1*DIGIT

Example values

  • 3495

Example

use headers::ContentLength;

let len = ContentLength(1_000);

Tuple Fields

0: u64