ContentType

Struct ContentType 

pub struct ContentType(/* private fields */);
Available on crate feature fullstack only.
Content-Type header, defined in RFC7231

The Content-Type header field indicates the media type of the associated representation: either the representation enclosed in the message payload or the selected representation, as determined by the message semantics. The indicated media type defines both the data format and how that data is intended to be processed by a recipient, within the scope of the received message semantics, after any content codings indicated by Content-Encoding are decoded.

Although the mime crate allows the mime options to be any slice, this crate forces the use of Vec. This is to make sure the same header can’t have more than 1 type. If this is an issue, it’s possible to implement Header on a custom struct.

ABNF

Content-Type = media-type

Example values

  • text/html; charset=utf-8
  • application/json

Examples

use headers::ContentType;

let ct = ContentType::json();

Implementations

Source

impl ContentType

pub fn json() -> ContentType

A constructor to easily create a Content-Type: application/json header.

pub fn text() -> ContentType

A constructor to easily create a Content-Type: text/plain header.

pub fn text_utf8() -> ContentType

A constructor to easily create a Content-Type: text/plain; charset=utf-8 header.

pub fn html() -> ContentType

A constructor to easily create a Content-Type: text/html header.

pub fn xml() -> ContentType

A constructor to easily create a Content-Type: text/xml header.

pub fn form_url_encoded() -> ContentType

A constructor to easily create a Content-Type: application/www-form-url-encoded header.

pub fn jpeg() -> ContentType

A constructor to easily create a Content-Type: image/jpeg header.

pub fn png() -> ContentType

A constructor to easily create a Content-Type: image/png header.

pub fn octet_stream() -> ContentType

A constructor to easily create a Content-Type: application/octet-stream header.