pub struct LastModified(/* private fields */);Available on crate feature
fullstack only.Expand description
Last-Modified header, defined in
RFC7232
The Last-Modified header field in a response provides a timestamp
indicating the date and time at which the origin server believes the
selected representation was last modified, as determined at the
conclusion of handling the request.
ABNF
Expires = HTTP-dateExample values
Sat, 29 Oct 1994 19:43:31 GMT
Example
use headers::LastModified;
use std::time::{Duration, SystemTime};
let modified = LastModified::from(
SystemTime::now() - Duration::from_secs(60 * 60 * 24)
);Trait Implementations
Sourceimpl Clone for LastModified
impl Clone for LastModified
Sourcefn clone(&self) -> LastModified
fn clone(&self) -> LastModified
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LastModified
impl Debug for LastModified
Sourceimpl From<LastModified> for SystemTime
impl From<LastModified> for SystemTime
Sourcefn from(date: LastModified) -> SystemTime
fn from(date: LastModified) -> SystemTime
Converts to this type from the input type.
Sourceimpl From<SystemTime> for LastModified
impl From<SystemTime> for LastModified
Sourcefn from(time: SystemTime) -> LastModified
fn from(time: SystemTime) -> LastModified
Converts to this type from the input type.
Sourceimpl Hash for LastModified
impl Hash for LastModified
Sourceimpl Header for LastModified
impl Header for LastModified
Sourcefn name() -> &'static HeaderName
fn name() -> &'static HeaderName
The name of this header.
Sourcefn decode<'i, I>(values: &mut I) -> Result<LastModified, Error>where
I: Iterator<Item = &'i HeaderValue>,
fn decode<'i, I>(values: &mut I) -> Result<LastModified, Error>where
I: Iterator<Item = &'i HeaderValue>,
Decode this type from an iterator of
HeaderValues.Sourceimpl Ord for LastModified
impl Ord for LastModified
Sourcefn cmp(&self, other: &LastModified) -> Ordering
fn cmp(&self, other: &LastModified) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LastModified
impl PartialEq for LastModified
Sourcefn eq(&self, other: &LastModified) -> bool
fn eq(&self, other: &LastModified) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for LastModified
impl PartialOrd for LastModified
impl Copy for LastModified
impl Eq for LastModified
impl StructuralPartialEq for LastModified