RetryAfter

Struct RetryAfter 

pub struct RetryAfter(/* private fields */);
Available on crate feature fullstack only.
The Retry-After header.

The Retry-After response-header field can be used with a 503 (Service Unavailable) response to indicate how long the service is expected to be unavailable to the requesting client. This field MAY also be used with any 3xx (Redirection) response to indicate the minimum time the user-agent is asked wait before issuing the redirected request. The value of this field can be either an HTTP-date or an integer number of seconds (in decimal) after the time of the response.

Examples

use std::time::{Duration, SystemTime};
use headers::RetryAfter;

let delay = RetryAfter::delay(Duration::from_secs(300));
let date = RetryAfter::date(SystemTime::now());

Retry-After header, defined in RFC7231

Implementations

Source

impl RetryAfter

pub fn date(time: SystemTime) -> RetryAfter

Create an RetryAfter header with a date value.

pub fn delay(dur: Duration) -> RetryAfter

Create an RetryAfter header with a date value.