TransferEncoding

Struct TransferEncoding 

pub struct TransferEncoding(/* private fields */);
Available on crate feature fullstack only.
Transfer-Encoding header, defined in RFC7230

The Transfer-Encoding header field lists the transfer coding names corresponding to the sequence of transfer codings that have been (or will be) applied to the payload body in order to form the message body.

Note that setting this header will remove any previously set Content-Length header, in accordance with RFC7230:

A sender MUST NOT send a Content-Length header field in any message that contains a Transfer-Encoding header field.

ABNF

Transfer-Encoding = 1#transfer-coding

Example values

  • chunked
  • gzip, chunked

Example

use headers::TransferEncoding;

let transfer = TransferEncoding::chunked();

Implementations

Source

impl TransferEncoding

pub fn chunked() -> TransferEncoding

Constructor for the most common Transfer-Encoding, chunked.

pub fn is_chunked(&self) -> bool

Returns whether this ends with the chunked encoding.