pub struct FileStream { /* private fields */ }fullstack only.Expand description
A payload for uploading files using streams.
The FileUpload struct allows you to upload files by streaming their data. It can be constructed
from a stream of bytes and can be sent as part of an HTTP request. This is particularly useful for
handling large files without loading them entirely into memory.
On the web, this uses the ReadableStream API to stream file data.
Implementations
Sourceimpl FileStream
impl FileStream
Sourcepub fn content_type(&self) -> Option<&str>
pub fn content_type(&self) -> Option<&str>
Get the content type of the file, if available.
Sourcepub fn body_mut(&mut self) -> Option<&mut BodyDataStream>
Available on crate feature server only.
pub fn body_mut(&mut self) -> Option<&mut BodyDataStream>
server only.Return the underlying body stream, assuming the FileStream was created by a server request.
Sourcepub async fn from_path(file: impl AsRef<Path>) -> Result<FileStream, Error>
Available on crate feature server only.
pub async fn from_path(file: impl AsRef<Path>) -> Result<FileStream, Error>
server only.Create a new FileStream from a file path. This is only available on the server.
Sourcepub fn from_raw(
name: String,
size: Option<u64>,
content_type: String,
body: BodyDataStream,
) -> FileStream
Available on crate feature server only.
pub fn from_raw( name: String, size: Option<u64>, content_type: String, body: BodyDataStream, ) -> FileStream
server only.Create a new FileStream from raw components.
This is meant to be used on the server where a file might not even exist but you still want to stream it to the client as a download.