pub struct Attempt<'a> { /* private fields */ }Available on crate feature
fullstack and non-WebAssembly only.Expand description
A type that holds information on the next request and previous requests in redirect chain.
Implementations
Sourceimpl<'a> Attempt<'a>
impl<'a> Attempt<'a>
Sourcepub fn status(&self) -> StatusCode
pub fn status(&self) -> StatusCode
Get the type of redirect.
Sourcepub fn previous(&self) -> &[Url]
pub fn previous(&self) -> &[Url]
Get the list of previous URLs that have already been requested in this chain.