Module server

Module server 

Available on crate feature server only.
Implementations of the server side of the server function call.

Structs

FullstackState
State used by FullstackState::render_handler to render a dioxus component with axum

Traits

DioxusRouterExt
A extension trait with utilities for integrating Dioxus with your Axum router.

Functions

render_handler
SSR renderer handler for Axum with added context injection.