ServerFunction

Struct ServerFunction 

pub struct ServerFunction { /* private fields */ }
Available on crate feature server only.
A function endpoint that can be called from the client.

Implementations

Source

impl ServerFunction

pub const fn new( method: Method, path: &'static str, handler: fn() -> MethodRouter<FullstackState>, ) -> ServerFunction

Create a new server function object from a MethodRouter

pub fn path(&self) -> &'static str

The path of the server function.

pub fn method(&self) -> Method

The HTTP method the server function expects.

pub fn collect() -> Vec<&'static ServerFunction>

Collect all globally registered server functions

pub fn method_router(&self) -> MethodRouter<FullstackState>

Create a MethodRouter for this server function that can be mounted on an axum::Router.

This runs the handler inside the required FullstackContext scope and populates FullstackContext so that the handler can use those features.

It also runs the server function inside a tokio LocalPool to allow !Send futures.

pub fn make_handler( method: Method, handler: fn(State<FullstackContext>, Request<Body>) -> Pin<Box<dyn Future<Output = Response<Body>>>>, ) -> MethodRouter<FullstackState>

Creates a new MethodRouter for the given method and !Send handler.

This is used internally by the ServerFunction to create the method router that this server function uses.