FullstackState

Struct FullstackState 

pub struct FullstackState { /* private fields */ }
Available on crate feature server only.
State used by FullstackState::render_handler to render a dioxus component with axum

Implementations

Source

impl FullstackState

pub fn headless() -> FullstackState

Create a headless FullstackState without a root component.

This won’t render pages, but can still be used to register server functions and serve static assets.

pub fn new<M>( config: ServeConfig, root: impl ComponentFunction<(), M> + Send + Sync + 'static, ) -> FullstackState
where M: 'static,

Create a new FullstackState

pub fn new_with_virtual_dom_factory( config: ServeConfig, build_virtual_dom: impl Fn() -> VirtualDom + Send + Sync + 'static, ) -> FullstackState

Create a new FullstackState with a custom VirtualDom factory. This method can be used to pass context into the root component of your application.

pub fn with_config(self, config: ServeConfig) -> FullstackState

Set the ServeConfig for this FullstackState

pub async fn render_handler( __arg0: State<FullstackState>, request: Request<Body>, ) -> Response<Body>

SSR renderer handler for Axum with added context injection.

Example
#![allow(non_snake_case)]
use std::sync::{Arc, Mutex};

use axum::routing::get;
use dioxus::prelude::*;
use dioxus_server::{FullstackState, render_handler, ServeConfig};

fn app() -> Element {
    rsx! {
        "hello!"
    }
}

#[tokio::main]
async fn main() {
    let addr = dioxus::cli_config::fullstack_address_or_localhost();
    let router = axum::Router::new()
        // Register server functions, etc.
        // Note you can use `register_server_functions_with_context`
        // to inject the context into server functions running outside
        // of an SSR render context.
        .fallback(get(render_handler))
        .with_state(FullstackState::new(ServeConfig::new(), app))
        .into_make_service();

    let listener = tokio::net::TcpListener::bind(addr).await.unwrap();
    axum::serve(listener, router).await.unwrap();
}