pub trait StdError: Debug + Display {
// Provided methods
fn source(&self) -> Option<&(dyn Error + 'static)> { ... }
fn description(&self) -> &str { ... }
fn cause(&self) -> Option<&dyn Error> { ... }
fn provide<'a>(&'a self, request: &mut Request<'a>) { ... }
}fullstack only.Expand description
Error is a trait representing the basic expectations for error values,
i.e., values of type E in Result<T, E>.
Errors must describe themselves through the Display and Debug
traits. Error messages are typically concise lowercase sentences without
trailing punctuation:
let err = "NaN".parse::<u32>().unwrap_err();
assert_eq!(err.to_string(), "invalid digit found in string");Error source
Errors may provide cause information. Error::source() is generally
used when errors cross “abstraction boundaries”. If one module must report
an error that is caused by an error from a lower-level module, it can allow
accessing that error via Error::source(). This makes it possible for the
high-level module to provide its own errors while also revealing some of the
implementation for debugging.
In error types that wrap an underlying error, the underlying error
should be either returned by the outer error’s Error::source(), or rendered
by the outer error’s Display implementation, but not both.
Example
Implementing the Error trait only requires that Debug and Display are implemented too.
use std::error::Error;
use std::fmt;
use std::path::PathBuf;
#[derive(Debug)]
struct ReadConfigError {
path: PathBuf
}
impl fmt::Display for ReadConfigError {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
let path = self.path.display();
write!(f, "unable to read configuration at {path}")
}
}
impl Error for ReadConfigError {}Provided Methods
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any.
Examples
use std::error::Error;
use std::fmt;
#[derive(Debug)]
struct SuperError {
source: SuperErrorSideKick,
}
impl fmt::Display for SuperError {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "SuperError is here!")
}
}
impl Error for SuperError {
fn source(&self) -> Option<&(dyn Error + 'static)> {
Some(&self.source)
}
}
#[derive(Debug)]
struct SuperErrorSideKick;
impl fmt::Display for SuperErrorSideKick {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "SuperErrorSideKick is here!")
}
}
impl Error for SuperErrorSideKick {}
fn get_super_error() -> Result<(), SuperError> {
Err(SuperError { source: SuperErrorSideKick })
}
fn main() {
match get_super_error() {
Err(e) => {
println!("Error: {e}");
println!("Caused by: {}", e.source().unwrap());
}
_ => println!("No error"),
}
}1.0.0 · Sourcefn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
fn description(&self) -> &str
use the Display impl or to_string()
if let Err(e) = "xc".parse::<u32>() {
// Print `e` itself, no need for description().
eprintln!("Error: {e}");
}fn cause(&self) -> Option<&dyn Error>
replaced by Error::source, which can support downcasting
Sourcefn provide<'a>(&'a self, request: &mut Request<'a>)
🔬This is a nightly-only experimental API. (error_generic_member_access)
fn provide<'a>(&'a self, request: &mut Request<'a>)
error_generic_member_access)Provides type-based access to context intended for error reports.
Used in conjunction with Request::provide_value and Request::provide_ref to extract
references to member variables from dyn Error trait objects.
Example
#![feature(error_generic_member_access)]
use core::fmt;
use core::error::{request_ref, Request};
#[derive(Debug)]
enum MyLittleTeaPot {
Empty,
}
#[derive(Debug)]
struct MyBacktrace {
// ...
}
impl MyBacktrace {
fn new() -> MyBacktrace {
// ...
}
}
#[derive(Debug)]
struct Error {
backtrace: MyBacktrace,
}
impl fmt::Display for Error {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "Example Error")
}
}
impl std::error::Error for Error {
fn provide<'a>(&'a self, request: &mut Request<'a>) {
request
.provide_ref::<MyBacktrace>(&self.backtrace);
}
}
fn main() {
let backtrace = MyBacktrace::new();
let error = Error { backtrace };
let dyn_error = &error as &dyn std::error::Error;
let backtrace_ref = request_ref::<MyBacktrace>(dyn_error).unwrap();
assert!(core::ptr::eq(&error.backtrace, backtrace_ref));
assert!(request_ref::<MyLittleTeaPot>(dyn_error).is_none());
}Delegating Impls
Warning: We recommend implementors avoid delegating implementations of provide to
source error implementations.
This method should expose context from the current piece of the source chain only, not from
sources that are exposed in the chain of sources. Delegating provide implementations cause
the same context to be provided by multiple errors in the chain of sources which can cause
unintended duplication of information in error reports or require heuristics to deduplicate.
In other words, the following implementation pattern for provide is discouraged and should
not be used for Error types exposed in public APIs to third parties.
struct MyError {
source: Error,
}
impl std::error::Error for MyError {
fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
Some(&self.source)
}
fn provide<'a>(&'a self, request: &mut Request<'a>) {
self.source.provide(request) // <--- Discouraged
}
}Implementations
Sourceimpl dyn Error
impl dyn Error
1.3.0 · Sourcepub fn is<T>(&self) -> boolwhere
T: Error + 'static,
pub fn is<T>(&self) -> boolwhere
T: Error + 'static,
Returns true if the inner type is the same as T.
1.3.0 · Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
Returns some reference to the inner value if it is of type T, or
None if it isn’t.
1.3.0 · Sourcepub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
pub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
Returns some mutable reference to the inner value if it is of type T, or
None if it isn’t.
Sourceimpl dyn Error + Send
impl dyn Error + Send
1.3.0 · Sourcepub fn is<T>(&self) -> boolwhere
T: Error + 'static,
pub fn is<T>(&self) -> boolwhere
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
1.3.0 · Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
1.3.0 · Sourcepub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
pub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
Sourceimpl dyn Error + Sync + Send
impl dyn Error + Sync + Send
1.3.0 · Sourcepub fn is<T>(&self) -> boolwhere
T: Error + 'static,
pub fn is<T>(&self) -> boolwhere
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
1.3.0 · Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
1.3.0 · Sourcepub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
pub fn downcast_mut<T>(&mut self) -> Option<&mut T>where
T: Error + 'static,
Forwards to the method defined on the type dyn Error.
Sourceimpl dyn Error
impl dyn Error
Sourcepub fn sources(&self) -> Source<'_> ⓘ
🔬This is a nightly-only experimental API. (error_iter)
pub fn sources(&self) -> Source<'_> ⓘ
error_iter)Returns an iterator starting with the current error and continuing with
recursively calling Error::source.
If you want to omit the current error and only use its sources,
use skip(1).
Examples
#![feature(error_iter)]
use std::error::Error;
use std::fmt;
#[derive(Debug)]
struct A;
#[derive(Debug)]
struct B(Option<Box<dyn Error + 'static>>);
impl fmt::Display for A {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "A")
}
}
impl fmt::Display for B {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "B")
}
}
impl Error for A {}
impl Error for B {
fn source(&self) -> Option<&(dyn Error + 'static)> {
self.0.as_ref().map(|e| e.as_ref())
}
}
let b = B(Some(Box::new(A)));
// let err : Box<Error> = b.into(); // or
let err = &b as &dyn Error;
let mut iter = err.sources();
assert_eq!("B".to_string(), iter.next().unwrap().to_string());
assert_eq!("A".to_string(), iter.next().unwrap().to_string());
assert!(iter.next().is_none());
assert!(iter.next().is_none());Trait Implementations
Sourceimpl AsRef<dyn Error> for Error
Available on crate feature std or non-anyhow_no_core_error only.
impl AsRef<dyn Error> for Error
std or non-anyhow_no_core_error only.Sourceimpl AsRef<dyn Error + Sync + Send> for Error
Available on crate feature std or non-anyhow_no_core_error only.
impl AsRef<dyn Error + Sync + Send> for Error
std or non-anyhow_no_core_error only.1.6.0 · Sourceimpl<'a> From<&str> for Box<dyn Error + 'a>
Available on non-no_global_oom_handling only.
impl<'a> From<&str> for Box<dyn Error + 'a>
no_global_oom_handling only.1.0.0 · Sourceimpl<'a> From<&str> for Box<dyn Error + Sync + Send + 'a>
Available on non-no_global_oom_handling only.
impl<'a> From<&str> for Box<dyn Error + Sync + Send + 'a>
no_global_oom_handling only.1.22.0 · Sourceimpl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + 'a>
Available on non-no_global_oom_handling only.
impl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + 'a>
no_global_oom_handling only.1.22.0 · Sourceimpl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + Sync + Send + 'a>
Available on non-no_global_oom_handling only.
impl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + Sync + Send + 'a>
no_global_oom_handling only.Sourcefn from(err: Cow<'b, str>) -> Box<dyn Error + Sync + Send + 'a>
fn from(err: Cow<'b, str>) -> Box<dyn Error + Sync + Send + 'a>
Converts a Cow into a box of dyn Error + Send + Sync.
Examples
use std::error::Error;
use std::borrow::Cow;
let a_cow_str_error = Cow::from("a str error");
let a_boxed_error = Box::<dyn Error + Send + Sync>::from(a_cow_str_error);
assert!(
size_of::<Box<dyn Error + Send + Sync>>() == size_of_val(&a_boxed_error))1.0.0 · Sourceimpl<'a, E> From<E> for Box<dyn Error + 'a>where
E: Error + 'a,
Available on non-no_global_oom_handling only.
impl<'a, E> From<E> for Box<dyn Error + 'a>where
E: Error + 'a,
no_global_oom_handling only.Sourcefn from(err: E) -> Box<dyn Error + 'a>
fn from(err: E) -> Box<dyn Error + 'a>
Converts a type of Error into a box of dyn Error.
Examples
use std::error::Error;
use std::fmt;
#[derive(Debug)]
struct AnError;
impl fmt::Display for AnError {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "An error")
}
}
impl Error for AnError {}
let an_error = AnError;
assert!(0 == size_of_val(&an_error));
let a_boxed_error = Box::<dyn Error>::from(an_error);
assert!(size_of::<Box<dyn Error>>() == size_of_val(&a_boxed_error))1.0.0 · Sourceimpl<'a, E> From<E> for Box<dyn Error + Sync + Send + 'a>
Available on non-no_global_oom_handling only.
impl<'a, E> From<E> for Box<dyn Error + Sync + Send + 'a>
no_global_oom_handling only.Sourcefn from(err: E) -> Box<dyn Error + Sync + Send + 'a>
fn from(err: E) -> Box<dyn Error + Sync + Send + 'a>
Converts a type of Error + Send + Sync into a box of
dyn Error + Send + Sync.
Examples
use std::error::Error;
use std::fmt;
#[derive(Debug)]
struct AnError;
impl fmt::Display for AnError {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "An error")
}
}
impl Error for AnError {}
unsafe impl Send for AnError {}
unsafe impl Sync for AnError {}
let an_error = AnError;
assert!(0 == size_of_val(&an_error));
let a_boxed_error = Box::<dyn Error + Send + Sync>::from(an_error);
assert!(
size_of::<Box<dyn Error + Send + Sync>>() == size_of_val(&a_boxed_error))Sourceimpl From<Error> for Box<dyn Error>
Available on crate feature std or non-anyhow_no_core_error only.
impl From<Error> for Box<dyn Error>
std or non-anyhow_no_core_error only.Sourceimpl From<Error> for Box<dyn Error + Send>
Available on crate feature std or non-anyhow_no_core_error only.
impl From<Error> for Box<dyn Error + Send>
std or non-anyhow_no_core_error only.Sourceimpl From<Error> for Box<dyn Error + Sync + Send>
Available on crate feature std or non-anyhow_no_core_error only.
impl From<Error> for Box<dyn Error + Sync + Send>
std or non-anyhow_no_core_error only.1.6.0 · Sourceimpl<'a> From<String> for Box<dyn Error + 'a>
Available on non-no_global_oom_handling only.
impl<'a> From<String> for Box<dyn Error + 'a>
no_global_oom_handling only.1.0.0 · Sourceimpl<'a> From<String> for Box<dyn Error + Sync + Send + 'a>
Available on non-no_global_oom_handling only.
impl<'a> From<String> for Box<dyn Error + Sync + Send + 'a>
no_global_oom_handling only.Implementors
impl !Error for &str
impl Error for AssetPathError
impl Error for AssetResolveError
impl Error for NativeAssetResolveError
impl Error for AssetServeError
impl Error for MountedError
impl Error for ResizeError
impl Error for VisibleError
impl Error for IncrementalRendererError
impl Error for EvalError
impl Error for dioxus::prelude::BorrowError
impl Error for dioxus::prelude::BorrowMutError
impl Error for ServerFnError
impl Error for CborRejection
impl Error for RequestError
impl Error for StreamingError
impl Error for TakeDataError
impl Error for WebsocketError
impl Error for MultipartRejection
impl Error for BytesRejection
impl Error for ExtensionRejection
impl Error for FailedToBufferBody
impl Error for FormRejection
impl Error for JsonRejection
impl Error for MatchedPathRejection
impl Error for PathRejection
impl Error for QueryRejection
impl Error for RawFormRejection
impl Error for RawPathParamsRejection
impl Error for StringRejection
impl Error for WebSocketUpgradeRejection
impl Error for Infallible
impl Error for FromBytesWithNulError
impl Error for core::slice::GetDisjointMutError
impl Error for VarError
impl Error for std::fs::TryLockError
impl Error for std::sync::mpsc::RecvTimeoutError
impl Error for std::sync::mpsc::TryRecvError
impl Error for HostRejection
impl Error for ParseAlphabetError
std only.impl Error for base64::decode::DecodeError
std only.impl Error for DecodeSliceError
std only.impl Error for EncodeSliceError
std only.impl Error for RoundingError
std only.impl Error for ciborium::value::error::Error
impl Error for cookie::parse::ParseError
impl Error for cookie_store::cookie::Error
impl Error for LiveViewError
impl Error for futures_channel::mpsc::TryRecvError
impl Error for gloo_net::error::Error
impl Error for WebSocketError
impl Error for hashbrown::TryReserveError
impl Error for RangeUnsatisfiableError
impl Error for httparse::Error
std only.impl Error for GetTimezoneError
impl Error for icu_collections::codepointtrie::error::Error
impl Error for icu_locale_core::parser::errors::ParseError
impl Error for PreferencesParseError
impl Error for indexmap::GetDisjointMutError
impl Error for libloading::error::Error
impl Error for InsertError
impl Error for matchit::error::MatchError
impl Error for multer::error::Error
impl Error for BernoulliError
std only.impl Error for rand::distr::uniform::Error
std only.impl Error for rand::distr::weighted::Error
std only.impl Error for StartError
std only.impl Error for regex_syntax::error::Error
std only.impl Error for rustls_pki_types::pem::Error
std only.impl Error for webpki::error::Error
std only.impl Error for EarlyDataError
std only.impl Error for EncodeError
std only.impl Error for EncryptError
std only.impl Error for rustls::error::Error
std only.impl Error for VerifierBuilderError
std only.impl Error for serde_qs::error::Error
impl Error for serde_urlencoded::ser::Error
impl Error for slab::GetDisjointMutError
std only.impl Error for PatchError
impl Error for time::error::Error
impl Error for Format
impl Error for InvalidFormatDescription
impl Error for Parse
impl Error for ParseFromDescription
impl Error for TryFromParsed
impl Error for tinystr::error::ParseError
impl Error for AnyDelimiterCodecError
impl Error for LinesCodecError
impl Error for TryAcquireError
impl Error for tokio::sync::broadcast::error::RecvError
impl Error for tokio::sync::broadcast::error::TryRecvError
impl Error for tokio::sync::mpsc::error::TryRecvError
impl Error for tokio::sync::oneshot::error::TryRecvError
impl Error for tungstenite::error::CapacityError
impl Error for tungstenite::error::CapacityError
impl Error for tungstenite::error::CapacityError
impl Error for tungstenite::error::Error
impl Error for tungstenite::error::Error
impl Error for tungstenite::error::Error
impl Error for tungstenite::error::ProtocolError
impl Error for tungstenite::error::ProtocolError
impl Error for tungstenite::error::ProtocolError
impl Error for tungstenite::error::SubProtocolError
impl Error for tungstenite::error::SubProtocolError
impl Error for tungstenite::error::SubProtocolError
impl Error for tungstenite::error::TlsError
impl Error for tungstenite::error::TlsError
impl Error for tungstenite::error::TlsError
impl Error for tungstenite::error::UrlError
impl Error for tungstenite::error::UrlError
impl Error for tungstenite::error::UrlError
impl Error for url::parser::ParseError
std only.impl Error for ZeroTrieBuildError
impl Error for UleError
impl Error for !
impl Error for WebAssetResolveError
impl Error for HttpError
impl Error for dioxus::prelude::dioxus_fullstack::axum_core::Error
impl Error for InvalidBoundary
impl Error for MultipartError
impl Error for FailedToDeserializePathParams
impl Error for InvalidUtf8InPathParam
impl Error for FailedToDeserializeForm
impl Error for FailedToDeserializeFormBody
impl Error for FailedToDeserializeQueryString
impl Error for InvalidFormContentType
impl Error for InvalidUtf8
impl Error for JsonDataError
impl Error for JsonSyntaxError
impl Error for dioxus::prelude::dioxus_fullstack::extract::rejection::LengthLimitError
impl Error for MatchedPathMissing
impl Error for MissingExtension
impl Error for MissingJsonContentType
impl Error for MissingPathParams
impl Error for NestedPathRejection
impl Error for UnknownBodyError
impl Error for ConnectionNotUpgradable
impl Error for InvalidConnectionHeader
impl Error for InvalidProtocolPseudoheader
impl Error for InvalidUpgradeHeader
impl Error for InvalidWebSocketVersionHeader
impl Error for MethodNotConnect
impl Error for MethodNotGet
impl Error for WebSocketKeyHeaderMissing
impl Error for dioxus::prelude::dioxus_fullstack::headers::Error
impl Error for InvalidHeaderName
impl Error for InvalidHeaderValue
impl Error for MaxSizeReached
impl Error for ToStrError
impl Error for InvalidMethod
impl Error for InvalidStatusCode
impl Error for dioxus::prelude::dioxus_fullstack::http::Error
impl Error for InvalidUri
impl Error for InvalidUriParts
impl Error for dioxus::prelude::dioxus_fullstack::reqwest::Error
impl Error for dioxus::prelude::dioxus_fullstack::serde::de::value::Error
std only.impl Error for UnorderedKeyError
impl Error for alloc::collections::TryReserveError
impl Error for FromVecWithNulError
impl Error for IntoStringError
impl Error for NulError
impl Error for FromUtf8Error
impl Error for FromUtf16Error
impl Error for LayoutError
impl Error for AllocError
impl Error for TryFromSliceError
impl Error for core::cell::BorrowError
impl Error for core::cell::BorrowMutError
impl Error for CharTryFromError
impl Error for ParseCharError
impl Error for DecodeUtf16Error
impl Error for TryFromCharError
impl Error for FromBytesUntilNulError
impl Error for core::fmt::Error
impl Error for core::net::parser::AddrParseError
impl Error for core::num::error::ParseIntError
impl Error for core::num::error::TryFromIntError
impl Error for ParseFloatError
impl Error for ParseBoolError
impl Error for Utf8Error
impl Error for TryFromFloatSecsError
impl Error for JoinPathsError
impl Error for WriterPanicked
impl Error for std::io::error::Error
impl Error for NormalizeError
impl Error for StripPrefixError
impl Error for ExitStatusError
impl Error for std::sync::mpsc::RecvError
impl Error for AccessError
impl Error for SystemTimeError
impl Error for FailedToResolveHost
impl Error for TypedHeaderRejection
impl Error for TryGetError
std only.impl Error for chrono::format::ParseError
core-error or std only.impl Error for ParseMonthError
std only.impl Error for OutOfRange
std only.impl Error for OutOfRangeError
std or core-error only.impl Error for ParseWeekdayError
std only.impl Error for IdnaErrors
impl Error for InvalidLength
std only.impl Error for data_encoding::DecodeError
std only.impl Error for SpecificationError
std only.impl Error for deranged::ParseIntError
impl Error for deranged::TryFromIntError
impl Error for InvalidBufferSize
std only.impl Error for InvalidOutputSize
std only.impl Error for ParseRouteError
impl Error for futures_channel::mpsc::RecvError
impl Error for futures_channel::mpsc::SendError
impl Error for Canceled
std only.impl Error for EnterError
impl Error for SpawnError
std only.impl Error for Aborted
std only.impl Error for AlreadyBorrowedError
impl Error for AlreadyBorrowedMutError
impl Error for ValueDroppedError
impl Error for getrandom::error::Error
impl Error for JsError
impl Error for NotJsError
impl Error for h2::error::Error
impl Error for http_body_util::limited::LengthLimitError
impl Error for httpdate::Error
impl Error for hyper_util::client::legacy::client::Error
impl Error for InvalidNameError
impl Error for hyper::error::Error
impl Error for DataError
impl Error for Errors
std only.impl Error for indexmap::TryReserveError
impl Error for PrefixLenError
impl Error for ipnet::parser::AddrParseError
impl Error for CapacityOverflowError
std only.impl Error for iri_string::normalize::error::Error
std only.impl Error for iri_string::template::error::Error
std only.impl Error for iri_string::validate::Error
std only.impl Error for js_sys::TryFromIntError
std only.impl Error for UnrecognizedCodeError
impl Error for UnrecognizedKeyError
impl Error for FromStrError
impl Error for Empty
std only.impl Error for OsError
std only.impl Error for regex_automata::dfa::dense::BuildError
std and dfa-build only.impl Error for regex_automata::nfa::thompson::error::BuildError
std only.impl Error for GroupInfoError
std only.impl Error for UnicodeWordBoundaryError
std only.impl Error for PatternIDError
std only.impl Error for SmallIndexError
std only.impl Error for StateIDError
std only.impl Error for regex_automata::util::search::MatchError
std only.impl Error for PatternSetInsertError
std only.impl Error for DeserializeError
std only.impl Error for SerializeError
std only.impl Error for regex_syntax::ast::Error
std only.impl Error for regex_syntax::hir::Error
std only.impl Error for CaseFoldError
std only.impl Error for UnicodeWordError
std only.impl Error for rustls_pki_types::server_name::AddrParseError
std only.impl Error for InvalidDnsNameError
std only.impl Error for UnsupportedOperationError
std only.impl Error for OtherError
std only.impl Error for serde_wasm_bindgen::error::Error
impl Error for serde_json::error::Error
impl Error for ComponentRange
impl Error for ConversionRange
impl Error for DifferentVariant
impl Error for InvalidVariant
impl Error for LengthDelimitedCodecError
impl Error for tokio::net::tcp::split_owned::ReuniteError
impl Error for tokio::net::unix::split_owned::ReuniteError
impl Error for TryCurrentError
impl Error for JoinError
impl Error for AcquireError
impl Error for tokio::sync::mutex::TryLockError
impl Error for tokio::sync::oneshot::error::RecvError
impl Error for tokio::sync::watch::error::RecvError
impl Error for tokio::time::error::Elapsed
impl Error for tokio::time::error::Error
impl Error for InvalidBackoff
impl Error for tower::timeout::error::Elapsed
impl Error for None
impl Error for SetGlobalDefaultError
std only.impl Error for ParseLevelError
std only.impl Error for ParseLevelFilterError
std only.impl Error for tracing_subscriber::filter::directive::ParseError
std only.impl Error for BadName
impl Error for FromEnvError
impl Error for tracing_subscriber::reload::Error
impl Error for TryInitError
std only.impl Error for uuid::error::Error
impl Error for walkdir::error::Error
impl<'a> Error for utf8::DecodeError<'a>
impl<'a> Error for BufReadDecoderError<'a>
impl<'a, K, V> Error for alloc::collections::btree::map::entry::OccupiedError<'a, K, V>
impl<'a, K, V, A> Error for std::collections::hash::map::OccupiedError<'a, K, V, A>
impl<'a, T> Error for &'a T
impl<A, S, V> Error for ConvertError<A, S, V>
no_zerocopy_core_error_1_81_0 or crate feature std only.impl<E> Error for Box<E>where
E: Error,
impl<E> Error for serde_path_to_error::Error<E>where
E: Error,
impl<I> Error for InputError<I>
std only.impl<I, C> Error for TreeError<I, C>
std only.impl<K, V> Error for TryIntoHeaderError<K, V>
impl<Role> Error for tungstenite::handshake::HandshakeError<Role>where
Role: HandshakeRole,
impl<Role> Error for tungstenite::handshake::HandshakeError<Role>where
Role: HandshakeRole,
impl<Role> Error for tungstenite::handshake::HandshakeError<Role>where
Role: HandshakeRole,
impl<Src, Dst> Error for AlignmentError<Src, Dst>
no_zerocopy_core_error_1_81_0 or crate feature std only.impl<Src, Dst> Error for SizeError<Src, Dst>
no_zerocopy_core_error_1_81_0 or crate feature std only.impl<Src, Dst> Error for ValidityError<Src, Dst>
no_zerocopy_core_error_1_81_0 or crate feature std only.impl<T> Error for std::sync::mpmc::error::SendTimeoutError<T>
impl<T> Error for std::sync::mpsc::TrySendError<T>
impl<T> Error for std::sync::oneshot::RecvTimeoutError<T>
impl<T> Error for std::sync::oneshot::TryRecvError<T>
impl<T> Error for std::sync::poison::TryLockError<T>
impl<T> Error for ciborium::de::error::Error<T>where
T: Debug,
impl<T> Error for ciborium::ser::error::Error<T>where
T: Debug,
impl<T> Error for tokio::sync::mpsc::error::SendTimeoutError<T>
time only.impl<T> Error for tokio::sync::mpsc::error::TrySendError<T>
impl<T> Error for SetError<T>where
T: Debug,
impl<T> Error for ThinBox<T>
impl<T> Error for Arc<T>
impl<T> Error for std::sync::mpsc::SendError<T>
impl<T> Error for PoisonError<T>
impl<T> Error for futures_channel::mpsc::TrySendError<T>where
T: Any,
impl<T> Error for futures_util::io::split::ReuniteError<T>where
T: Any,
std only.impl<T> Error for iri_string::template::error::CreationError<T>where
T: Debug,
std only.impl<T> Error for iri_string::types::generic::error::CreationError<T>where
T: Debug,
std only.impl<T> Error for PollSendError<T>where
T: Debug,
impl<T> Error for AsyncFdTryNewError<T>
impl<T> Error for tokio::sync::broadcast::error::SendError<T>where
T: Debug,
impl<T> Error for tokio::sync::mpsc::error::SendError<T>
impl<T> Error for SetOnceError<T>where
T: Debug,
impl<T> Error for tokio::sync::watch::error::SendError<T>
impl<T, E> Error for TryChunksError<T, E>
std only.impl<T, E> Error for TryReadyChunksError<T, E>
std only.impl<T, Item> Error for futures_util::stream::stream::split::ReuniteError<T, Item>where
T: Any,
std only.