pub struct ServerFunction { /* private fields */ }Available on crate feature
server only.Expand description
A function endpoint that can be called from the client.
Implementations
Sourceimpl ServerFunction
impl ServerFunction
Sourcepub const fn new(
method: Method,
path: &'static str,
handler: fn() -> MethodRouter<FullstackState>,
) -> ServerFunction
pub const fn new( method: Method, path: &'static str, handler: fn() -> MethodRouter<FullstackState>, ) -> ServerFunction
Create a new server function object from a MethodRouter
Sourcepub fn collect() -> Vec<&'static ServerFunction>
pub fn collect() -> Vec<&'static ServerFunction>
Collect all globally registered server functions
Sourcepub fn method_router(&self) -> MethodRouter<FullstackState>
pub fn method_router(&self) -> MethodRouter<FullstackState>
Create a MethodRouter for this server function that can be mounted on an axum::Router.
This runs the handler inside the required FullstackContext scope and populates
FullstackContext so that the handler can use those features.
It also runs the server function inside a tokio LocalPool to allow !Send futures.
Sourcepub fn make_handler(
method: Method,
handler: fn(State<FullstackContext>, Request<Body>) -> Pin<Box<dyn Future<Output = Response<Body>>>>,
) -> MethodRouter<FullstackState>
pub fn make_handler( method: Method, handler: fn(State<FullstackContext>, Request<Body>) -> Pin<Box<dyn Future<Output = Response<Body>>>>, ) -> MethodRouter<FullstackState>
Creates a new MethodRouter for the given method and !Send handler.
This is used internally by the ServerFunction to create the method router that this
server function uses.